You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2015/11/12 09:18:19 UTC

[08/33] camel git commit: Camel component docs. Fixed test after adding group into the docs.

Camel component docs. Fixed test after adding group into the docs.


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/2bc0d40b
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/2bc0d40b
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/2bc0d40b

Branch: refs/heads/master
Commit: 2bc0d40b9cea8de5927aebf4c7e1a2931f3c1235
Parents: d11c18d
Author: Claus Ibsen <da...@apache.org>
Authored: Thu Nov 12 08:00:27 2015 +0100
Committer: Claus Ibsen <da...@apache.org>
Committed: Thu Nov 12 09:19:14 2015 +0100

----------------------------------------------------------------------
 .../component/dataset/DataSetEndpoint.java      | 14 ++---
 .../camel/component/mock/MockEndpoint.java      | 16 +++---
 .../apache/camel/impl/DefaultCamelContext.java  | 54 ++++++++++++--------
 ...ponentConfigurationAndDocumentationTest.java |  4 +-
 ...ponentConfigurationAndDocumentationTest.java |  3 +-
 ...ponentConfigurationAndDocumentationTest.java |  4 +-
 ...ponentConfigurationAndDocumentationTest.java |  6 +--
 ...ponentConfigurationAndDocumentationTest.java |  8 ++-
 ...ponentConfigurationAndDocumentationTest.java | 10 +---
 ...ponentConfigurationAndDocumentationTest.java |  4 +-
 ...ponentConfigurationAndDocumentationTest.java |  7 +--
 ...ponentConfigurationAndDocumentationTest.java |  4 +-
 ...ponentConfigurationAndDocumentationTest.java |  5 +-
 ...ponentConfigurationAndDocumentationTest.java | 12 ++---
 ...ponentConfigurationAndDocumentationTest.java |  5 +-
 ...ponentConfigurationAndDocumentationTest.java |  4 +-
 ...ponentConfigurationAndDocumentationTest.java |  6 +--
 ...ponentConfigurationAndDocumentationTest.java |  5 +-
 .../management/ManagedCamelContextTest.java     | 24 ++++-----
 .../management/ManagedEndpointExplainTest.java  |  2 +-
 20 files changed, 99 insertions(+), 98 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/main/java/org/apache/camel/component/dataset/DataSetEndpoint.java
----------------------------------------------------------------------
diff --git a/camel-core/src/main/java/org/apache/camel/component/mock/MockEndpoint.java b/camel-core/src/main/java/org/apache/camel/component/mock/MockEndpoint.java
index c6732f1..672e902 100644
--- a/camel-core/src/main/java/org/apache/camel/component/mock/MockEndpoint.java
+++ b/camel-core/src/main/java/org/apache/camel/component/mock/MockEndpoint.java
@@ -117,21 +117,21 @@ public class MockEndpoint extends DefaultEndpoint implements BrowsableEndpoint {
 
     @UriPath(description = "Name of mock endpoint") @Metadata(required = "true")
     private String name;
-    @UriParam(defaultValue = "-1")
+    @UriParam(label = "producer", defaultValue = "-1")
     private int expectedCount;
-    @UriParam(defaultValue = "0")
+    @UriParam(label = "producer", defaultValue = "0")
     private long sleepForEmptyTest;
-    @UriParam(defaultValue = "0")
+    @UriParam(label = "producer", defaultValue = "0")
     private long resultWaitTime;
-    @UriParam(defaultValue = "0")
+    @UriParam(label = "producer", defaultValue = "0")
     private long resultMinimumWaitTime;
-    @UriParam(defaultValue = "0")
+    @UriParam(label = "producer", defaultValue = "0")
     private long assertPeriod;
-    @UriParam(defaultValue = "-1")
+    @UriParam(label = "producer", defaultValue = "-1")
     private int retainFirst;
-    @UriParam(defaultValue = "-1")
+    @UriParam(label = "producer", defaultValue = "-1")
     private int retainLast;
-    @UriParam(defaultValue = "true")
+    @UriParam(label = "producer,advanced", defaultValue = "true")
     private boolean copyOnExchange = true;
 
     public MockEndpoint(String endpointUri, Component component) {

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/main/java/org/apache/camel/impl/DefaultCamelContext.java
----------------------------------------------------------------------
diff --git a/camel-core/src/main/java/org/apache/camel/impl/DefaultCamelContext.java b/camel-core/src/main/java/org/apache/camel/impl/DefaultCamelContext.java
index 50f7060..f7b3033 100644
--- a/camel-core/src/main/java/org/apache/camel/impl/DefaultCamelContext.java
+++ b/camel-core/src/main/java/org/apache/camel/impl/DefaultCamelContext.java
@@ -1836,6 +1836,7 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
                 // find type and description from the json schema
                 String type = null;
                 String kind = null;
+                String group = null;
                 String label = null;
                 String required = null;
                 String javaType = null;
@@ -1846,6 +1847,7 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
                     if (name.equals(row.get("name"))) {
                         type = row.get("type");
                         kind = row.get("kind");
+                        group = row.get("group");
                         label = row.get("label");
                         required = row.get("required");
                         javaType = row.get("javaType");
@@ -1857,13 +1859,14 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
                 }
 
                 // add as selected row
-                selected.put(name, new String[]{name, kind, label, required, type, javaType, deprecated, value, defaultValue, description});
+                selected.put(name, new String[]{name, kind, group, label, required, type, javaType, deprecated, value, defaultValue, description});
             }
 
             // include other rows
             for (Map<String, String> row : rows) {
                 String name = row.get("name");
                 String kind = row.get("kind");
+                String group = row.get("group");
                 String label = row.get("label");
                 String required = row.get("required");
                 String value = row.get("value");
@@ -1878,7 +1881,7 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
                 if (includeAllOptions) {
                     // add as selected row
                     if (!selected.containsKey(name)) {
-                        selected.put(name, new String[]{name, kind, label, required, type, javaType, deprecated, value, defaultValue, description});
+                        selected.put(name, new String[]{name, kind, group, label, required, type, javaType, deprecated, value, defaultValue, description});
                     }
                 }
             }
@@ -1898,14 +1901,15 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
 
                 String name = row[0];
                 String kind = row[1];
-                String label = row[2];
-                String required = row[3];
-                String type = row[4];
-                String javaType = row[5];
-                String deprecated = row[6];
-                String value = row[7];
-                String defaultValue = row[8];
-                String description = row[9];
+                String group = row[2];
+                String label = row[3];
+                String required = row[4];
+                String type = row[5];
+                String javaType = row[6];
+                String deprecated = row[7];
+                String value = row[8];
+                String defaultValue = row[9];
+                String description = row[10];
 
                 // add json of the option
                 buffer.append(StringQuoteHelper.doubleQuote(name)).append(": { ");
@@ -1913,6 +1917,9 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
                 if (kind != null) {
                     csb.append("\"kind\": \"" + kind + "\"");
                 }
+                if (group != null) {
+                    csb.append("\"group\": \"" + group + "\"");
+                }
                 if (label != null) {
                     csb.append("\"label\": \"" + label + "\"");
                 }
@@ -1989,6 +1996,7 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
                 // find type and description from the json schema
                 String type = null;
                 String kind = null;
+                String group = null;
                 String label = null;
                 String required = null;
                 String javaType = null;
@@ -1999,6 +2007,7 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
                     if (name.equals(row.get("name"))) {
                         type = row.get("type");
                         kind = row.get("kind");
+                        group = row.get("group");
                         label = row.get("label");
                         required = row.get("required");
                         javaType = row.get("javaType");
@@ -2010,13 +2019,14 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
                 }
 
                 // remember this option from the uri
-                uriOptions.put(name, new String[]{name, kind, label, required, type, javaType, deprecated, value, defaultValue, description});
+                uriOptions.put(name, new String[]{name, kind, group, label, required, type, javaType, deprecated, value, defaultValue, description});
             }
 
             // include other rows
             for (Map<String, String> row : rows) {
                 String name = row.get("name");
                 String kind = row.get("kind");
+                String group = row.get("group");
                 String label = row.get("label");
                 String required = row.get("required");
                 String value = row.get("value");
@@ -2036,7 +2046,7 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
                         if (isUriOption) {
                             selected.put(name, uriOptions.get(name));
                         } else {
-                            selected.put(name, new String[]{name, kind, label, required, type, javaType, deprecated, value, defaultValue, description});
+                            selected.put(name, new String[]{name, kind, group, label, required, type, javaType, deprecated, value, defaultValue, description});
                         }
                     }
                 }
@@ -2059,14 +2069,15 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
 
                 String name = row[0];
                 String kind = row[1];
-                String label = row[2];
-                String required = row[3];
-                String type = row[4];
-                String javaType = row[5];
-                String deprecated = row[6];
-                String value = row[7];
-                String defaultValue = row[8];
-                String description = row[9];
+                String group = row[2];
+                String label = row[3];
+                String required = row[4];
+                String type = row[5];
+                String javaType = row[6];
+                String deprecated = row[7];
+                String value = row[8];
+                String defaultValue = row[9];
+                String description = row[10];
 
                 // add json of the option
                 buffer.append(StringQuoteHelper.doubleQuote(name)).append(": { ");
@@ -2074,6 +2085,9 @@ public class DefaultCamelContext extends ServiceSupport implements ModelCamelCon
                 if (kind != null) {
                     csb.append("\"kind\": \"" + kind + "\"");
                 }
+                if (group != null) {
+                    csb.append("\"group\": \"" + group + "\"");
+                }
                 if (label != null) {
                     csb.append("\"label\": \"" + label + "\"");
                 }

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/bean/BeanComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/bean/BeanComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/bean/BeanComponentConfigurationAndDocumentationTest.java
index dce762c..3cde533 100644
--- a/camel-core/src/test/java/org/apache/camel/component/bean/BeanComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/bean/BeanComponentConfigurationAndDocumentationTest.java
@@ -41,8 +41,8 @@ public class BeanComponentConfigurationAndDocumentationTest extends ContextTestS
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"method\": { \"kind\": \"parameter\", \"type\": \"string\""));
-        assertTrue(json.contains("\"cache\": { \"kind\": \"parameter\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"method\": { \"kind\": \"parameter\", \"group\": \"producer\", \"type\": \"string\""));
+        assertTrue(json.contains("\"cache\": { \"kind\": \"parameter\", \"group\": \"advanced\", \"label\": \"advanced\", \"type\": \"boolean\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/browse/BrowseComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/browse/BrowseComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/browse/BrowseComponentConfigurationAndDocumentationTest.java
index 507cf06..f09bccf 100644
--- a/camel-core/src/test/java/org/apache/camel/component/browse/BrowseComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/browse/BrowseComponentConfigurationAndDocumentationTest.java
@@ -41,7 +41,8 @@ public class BrowseComponentConfigurationAndDocumentationTest extends ContextTes
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"synchronous\": { \"kind\": \"parameter\", \"label\": \"advanced\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"name\": { \"kind\": \"path\", \"group\": \"common\", \"required\": \"true\", \"type\": \"string\""));
+        assertTrue(json.contains("\"synchronous\": { \"kind\": \"parameter\", \"group\": \"advanced\", \"label\": \"advanced\", \"type\": \"boolean\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/controlbus/ControlBusComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/controlbus/ControlBusComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/controlbus/ControlBusComponentConfigurationAndDocumentationTest.java
index 1c36a61..f00a555 100644
--- a/camel-core/src/test/java/org/apache/camel/component/controlbus/ControlBusComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/controlbus/ControlBusComponentConfigurationAndDocumentationTest.java
@@ -42,8 +42,8 @@ public class ControlBusComponentConfigurationAndDocumentationTest extends Contex
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"action\": { \"kind\": \"parameter\", \"type\": \"string\""));
-        assertTrue(json.contains("\"async\": { \"kind\": \"parameter\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"action\": { \"kind\": \"parameter\", \"group\": \"producer\", \"type\": \"string\""));
+        assertTrue(json.contains("\"async\": { \"kind\": \"parameter\", \"group\": \"producer\", \"type\": \"boolean\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/dataformat/DataFormatComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/dataformat/DataFormatComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/dataformat/DataFormatComponentConfigurationAndDocumentationTest.java
index 914deeb..a483dbb 100644
--- a/camel-core/src/test/java/org/apache/camel/component/dataformat/DataFormatComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/dataformat/DataFormatComponentConfigurationAndDocumentationTest.java
@@ -45,10 +45,10 @@ public class DataFormatComponentConfigurationAndDocumentationTest extends Contex
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"name\": { \"kind\": \"path\", \"required\": \"true\", \"type\": \"string\", \"javaType\": \"java.lang.String\","
+        assertTrue(json.contains("\"name\": { \"kind\": \"path\", \"group\": \"producer\", \"required\": \"true\", \"type\": \"string\", \"javaType\": \"java.lang.String\","
                         + " \"deprecated\": \"false\", \"description\": \"Name of data format\" }"));
-        assertTrue(json.contains("\"operation\": { \"kind\": \"path\", \"required\": \"true\", \"type\": \"string\""));
-        assertTrue(json.contains("\"synchronous\": { \"kind\": \"parameter\", \"label\": \"advanced\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"operation\": { \"kind\": \"path\", \"group\": \"producer\", \"required\": \"true\", \"type\": \"string\""));
+        assertTrue(json.contains("\"synchronous\": { \"kind\": \"parameter\", \"group\": \"advanced\", \"label\": \"advanced\", \"type\": \"boolean\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/dataset/DataSetComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/dataset/DataSetComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/dataset/DataSetComponentConfigurationAndDocumentationTest.java
index dc643ca..9a893d8 100644
--- a/camel-core/src/test/java/org/apache/camel/component/dataset/DataSetComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/dataset/DataSetComponentConfigurationAndDocumentationTest.java
@@ -41,11 +41,9 @@ public class DataSetComponentConfigurationAndDocumentationTest extends ContextTe
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"preloadSize\": { \"kind\": \"parameter\", \"type\": \"integer\""));
-        assertTrue(json.contains("\"minRate\": { \"kind\": \"parameter\", \"type\": \"integer\""));
-        assertTrue(json.contains("\"exchangePattern\": { \"kind\": \"parameter\", \"label\": \"advanced\", \"type\": \"string\", \"javaType\": \"org.apache.camel.ExchangePattern\""
-                + ", \"enum\": [ \"InOnly\", \"RobustInOnly\", \"InOut\", \"InOptionalOut\", \"OutOnly\", \"RobustOutOnly\", \"OutIn\", \"OutOptionalIn\" ]"));
-        assertTrue(json.contains("\"InOut\""));
+        assertTrue(json.contains("\"name\": { \"kind\": \"path\", \"group\": \"common\", \"required\": \"true\", \"type\""));
+        assertTrue(json.contains("\"kind\": \"parameter\", \"group\": \"consuner\", \"label\": \"consuner\", \"type\": \"integer\""));
+        assertTrue(json.contains("\"retainFirst\": { \"kind\": \"parameter\", \"group\": \"producer\", \"label\": \"producer\", \"type\": \"integer"));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/direct/DirectComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/direct/DirectComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/direct/DirectComponentConfigurationAndDocumentationTest.java
index 43823e9..72360e1 100644
--- a/camel-core/src/test/java/org/apache/camel/component/direct/DirectComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/direct/DirectComponentConfigurationAndDocumentationTest.java
@@ -41,8 +41,8 @@ public class DirectComponentConfigurationAndDocumentationTest extends ContextTes
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"timeout\": { \"kind\": \"parameter\", \"label\": \"producer\", \"type\": \"integer\""));
-        assertTrue(json.contains("\"block\": { \"kind\": \"parameter\", \"label\": \"producer\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"name\": { \"kind\": \"path\", \"group\": \"common\", \"required\": \"true\", \"type\": \"string\""));
+        assertTrue(json.contains("\"timeout\": { \"kind\": \"parameter\", \"group\": \"producer\", \"label\": \"producer\", \"type\": \"integer\""));
     }
 
     @Test
@@ -57,12 +57,6 @@ public class DirectComponentConfigurationAndDocumentationTest extends ContextTes
         CamelContext context = new DefaultCamelContext();
         String json = context.getComponentParameterJsonSchema("direct");
         assertNotNull("Should have found some auto-generated JSON", json);
-        log.info(json);
-
-        // should include javadoc
-        assertTrue("Should include javadoc", json.contains("\"timeout\": { \"kind\": \"parameter\", \"label\": \"producer\","
-                + " \"type\": \"integer\", \"javaType\": \"long\", \"deprecated\": \"false\", \"defaultValue\": \"30000\","
-                + " \"description\": \"The timeout value to use if block is enabled."));
     }
 
 }

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/directvm/DirectVmComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/directvm/DirectVmComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/directvm/DirectVmComponentConfigurationAndDocumentationTest.java
index f548ce4..fc4828c 100644
--- a/camel-core/src/test/java/org/apache/camel/component/directvm/DirectVmComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/directvm/DirectVmComponentConfigurationAndDocumentationTest.java
@@ -41,8 +41,8 @@ public class DirectVmComponentConfigurationAndDocumentationTest extends ContextT
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"timeout\": { \"kind\": \"parameter\", \"label\": \"producer\", \"type\": \"integer\""));
-        assertTrue(json.contains("\"block\": { \"kind\": \"parameter\", \"label\": \"producer\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"name\": { \"kind\": \"path\", \"group\": \"common\", \"required\": \"true\", \"type\": \"string\""));
+        assertTrue(json.contains("\"timeout\": { \"kind\": \"parameter\", \"group\": \"producer\", \"label\": \"producer\", \"type\": \"integer\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/file/FileComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/file/FileComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/file/FileComponentConfigurationAndDocumentationTest.java
index 65c67a9..35f0072 100644
--- a/camel-core/src/test/java/org/apache/camel/component/file/FileComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/file/FileComponentConfigurationAndDocumentationTest.java
@@ -41,9 +41,10 @@ public class FileComponentConfigurationAndDocumentationTest extends ContextTestS
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"doneFileName\": { \"kind\": \"parameter\", \"label\": \"producer\", \"type\": \"string\""));
-        assertTrue(json.contains("\"exclude\": { \"kind\": \"parameter\", \"label\": \"consumer,filter\", \"type\": \"string\""));
-        assertTrue(json.contains("\"delete\": { \"kind\": \"parameter\", \"label\": \"consumer\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"directoryName\": { \"kind\": \"path\", \"group\": \"common\", \"required\": \"true\""));
+        assertTrue(json.contains("\"doneFileName\": { \"kind\": \"parameter\", \"group\": \"producer\", \"label\": \"producer\", \"type\": \"string\""));
+        assertTrue(json.contains("\"autoCreate\": { \"kind\": \"parameter\", \"group\": \"advanced\", \"label\": \"advanced\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"readLockMinAge\": { \"kind\": \"parameter\", \"group\": \"lock\", \"label\": \"consumer,lock\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/language/LanguageComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/language/LanguageComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/language/LanguageComponentConfigurationAndDocumentationTest.java
index 4003753..cb3bfdb 100644
--- a/camel-core/src/test/java/org/apache/camel/component/language/LanguageComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/language/LanguageComponentConfigurationAndDocumentationTest.java
@@ -41,8 +41,8 @@ public class LanguageComponentConfigurationAndDocumentationTest extends ContextT
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"script\": { \"kind\": \"parameter\", \"type\": \"string\""));
-        assertTrue(json.contains("\"cacheScript\": { \"kind\": \"parameter\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"languageName\": { \"kind\": \"path\", \"group\": \"producer\", \"required\": \"true\""));
+        assertTrue(json.contains("\"script\": { \"kind\": \"parameter\", \"group\": \"producer\", \"type\": \"string\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/log/LogComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/log/LogComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/log/LogComponentConfigurationAndDocumentationTest.java
index 64e3d81..d61c7fd 100644
--- a/camel-core/src/test/java/org/apache/camel/component/log/LogComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/log/LogComponentConfigurationAndDocumentationTest.java
@@ -41,8 +41,9 @@ public class LogComponentConfigurationAndDocumentationTest extends ContextTestSu
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"level\": { \"kind\": \"parameter\", \"type\": \"string\""));
-        assertTrue(json.contains("\"groupInterval\": { \"kind\": \"parameter\", \"type\": \"integer\""));
+        assertTrue(json.contains("\"loggerName\": { \"kind\": \"path\", \"group\": \"producer\", \"required\": \"true\""));
+        assertTrue(json.contains("\"level\": { \"kind\": \"parameter\", \"group\": \"producer\", \"type\": \"string\""));
+        assertTrue(json.contains("\"showBody\": { \"kind\": \"parameter\", \"group\": \"formatting\", \"label\": \"formatting\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/mock/MockComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/mock/MockComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/mock/MockComponentConfigurationAndDocumentationTest.java
index e5bea1d..28407b1 100644
--- a/camel-core/src/test/java/org/apache/camel/component/mock/MockComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/mock/MockComponentConfigurationAndDocumentationTest.java
@@ -41,9 +41,9 @@ public class MockComponentConfigurationAndDocumentationTest extends ContextTestS
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"name\": { \"kind\": \"path\", \"required\": \"true\", \"type\": \"string\""));
-        assertTrue(json.contains("\"expectedCount\": { \"kind\": \"parameter\", \"type\": \"integer\""));
-        assertTrue(json.contains("\"retainFirst\": { \"kind\": \"parameter\", \"type\": \"integer\""));
+        assertTrue(json.contains("\"name\": { \"kind\": \"path\", \"group\": \"producer\", \"required\": \"true\""));
+        assertTrue(json.contains("\"expectedCount\": { \"kind\": \"parameter\", \"group\": \"producer\", \"label\": \"producer\""));
+        assertTrue(json.contains("\"retainFirst\": { \"kind\": \"parameter\", \"group\": \"producer\", \"label\": \"producer\""));
     }
 
     @Test
@@ -51,10 +51,8 @@ public class MockComponentConfigurationAndDocumentationTest extends ContextTestS
         String json = context.explainEndpointJson("mock:foo?retainFirst=10", true);
         assertNotNull(json);
 
-        assertTrue(json.contains("\"name\": { \"kind\": \"path\", \"required\": \"true\", \"type\": \"string\", \"javaType\": \"java.lang.String\","
-                + " \"deprecated\": \"false\", \"value\": \"foo\", \"description\": \"Name of mock endpoint\""));
-        assertTrue(json.contains("\"expectedCount\": { \"kind\": \"parameter\", \"type\": \"integer\""));
-        assertTrue(json.contains("\"retainFirst\": { \"kind\": \"parameter\", \"type\": \"integer\""));
+        assertTrue(json.contains("\"retainFirst\": { \"kind\": \"parameter\", \"label\": \"producer\", \"type\": \"integer\""
+                + ", \"javaType\": \"int\", \"deprecated\": \"false\", \"value\": \"10\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/seda/SedaComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/seda/SedaComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/seda/SedaComponentConfigurationAndDocumentationTest.java
index c1c2973..00700ce 100644
--- a/camel-core/src/test/java/org/apache/camel/component/seda/SedaComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/seda/SedaComponentConfigurationAndDocumentationTest.java
@@ -41,9 +41,8 @@ public class SedaComponentConfigurationAndDocumentationTest extends ContextTestS
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"concurrentConsumers\": { \"kind\": \"parameter\", \"label\": \"consumer\", \"type\": \"integer\""));
-        assertTrue(json.contains("\"timeout\": { \"kind\": \"parameter\", \"label\": \"producer\", \"type\": \"integer\""));
-        assertTrue(json.contains("\"blockWhenFull\": { \"kind\": \"parameter\", \"label\": \"producer\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"concurrentConsumers\": { \"kind\": \"parameter\", \"group\": \"consumer\", \"label\": \"consumer\""));
+        assertTrue(json.contains("\"timeout\": { \"kind\": \"parameter\", \"group\": \"producer\", \"label\": \"producer\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/test/TestComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/test/TestComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/test/TestComponentConfigurationAndDocumentationTest.java
index 8fcebc7..ef3d009 100644
--- a/camel-core/src/test/java/org/apache/camel/component/test/TestComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/test/TestComponentConfigurationAndDocumentationTest.java
@@ -41,8 +41,8 @@ public class TestComponentConfigurationAndDocumentationTest extends ContextTestS
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"retainFirst\": { \"kind\": \"parameter\", \"type\": \"integer\""));
-        assertTrue(json.contains("\"timeout\": { \"kind\": \"parameter\", \"type\": \"integer\""));
+        assertTrue(json.contains("\"name\": { \"kind\": \"path\", \"group\": \"producer\", \"required\": \"true\""));
+        assertTrue(json.contains("\"retainFirst\": { \"kind\": \"parameter\", \"group\": \"producer\", \"label\": \"producer\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/timer/TimerComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/timer/TimerComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/timer/TimerComponentConfigurationAndDocumentationTest.java
index 141f8ea..c8fe793 100644
--- a/camel-core/src/test/java/org/apache/camel/component/timer/TimerComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/timer/TimerComponentConfigurationAndDocumentationTest.java
@@ -41,9 +41,9 @@ public class TimerComponentConfigurationAndDocumentationTest extends ContextTest
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"timerName\": { \"kind\": \"path\", \"required\": \"true\", \"type\": \"string\", \"javaType\": \"java.lang.String\""
-                + ", \"deprecated\": \"false\", \"description\": \"The name of the timer\" }"));
-        assertTrue(json.contains("\"delay\": { \"kind\": \"parameter\", \"type\": \"integer\""));
+        assertTrue(json.contains("\"timerName\": { \"kind\": \"path\", \"group\": \"consumer\", \"required\": \"true\""));
+        assertTrue(json.contains("\"delay\": { \"kind\": \"parameter\", \"group\": \"consumer\", \"type\": \"integer\""));
+        assertTrue(json.contains("\"timer\": { \"kind\": \"parameter\", \"group\": \"advanced\", \"label\": \"advanced\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/component/xslt/XsltComponentConfigurationAndDocumentationTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/component/xslt/XsltComponentConfigurationAndDocumentationTest.java b/camel-core/src/test/java/org/apache/camel/component/xslt/XsltComponentConfigurationAndDocumentationTest.java
index 0552c4a..45d3a7e 100644
--- a/camel-core/src/test/java/org/apache/camel/component/xslt/XsltComponentConfigurationAndDocumentationTest.java
+++ b/camel-core/src/test/java/org/apache/camel/component/xslt/XsltComponentConfigurationAndDocumentationTest.java
@@ -41,8 +41,9 @@ public class XsltComponentConfigurationAndDocumentationTest extends ContextTestS
         String json = compConf.createParameterJsonSchema();
         assertNotNull(json);
 
-        assertTrue(json.contains("\"contentCache\": { \"kind\": \"parameter\", \"type\": \"boolean\", \"javaType\": \"boolean\", \"deprecated\": \"false\", \"defaultValue\": \"true\""));
-        assertTrue(json.contains("\"synchronous\": { \"kind\": \"parameter\", \"label\": \"advanced\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"resourceUri\": { \"kind\": \"path\", \"group\": \"producer\", \"required\": \"true\""));
+        assertTrue(json.contains("\"allowStAX\": { \"kind\": \"parameter\", \"group\": \"producer\", \"type\": \"boolean\""));
+        assertTrue(json.contains("\"transformerFactoryClass\": { \"kind\": \"parameter\", \"group\": \"advanced\", \"label\": \"advanced\""));
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/management/ManagedCamelContextTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/management/ManagedCamelContextTest.java b/camel-core/src/test/java/org/apache/camel/management/ManagedCamelContextTest.java
index 3677611..ab76a87 100644
--- a/camel-core/src/test/java/org/apache/camel/management/ManagedCamelContextTest.java
+++ b/camel-core/src/test/java/org/apache/camel/management/ManagedCamelContextTest.java
@@ -274,12 +274,10 @@ public class ManagedCamelContextTest extends ManagementTestSupport {
         assertTrue(json.contains("\"scheme\": \"log\""));
         assertTrue(json.contains("\"label\": \"core,monitoring\""));
 
-        assertTrue(json.contains("\"groupDelay\": { \"kind\": \"parameter\", \"type\": \"integer\", \"javaType\": \"java.lang.Long\", \"deprecated\": \"false\", \"value\": \"2000\","
-                + " \"description\": \"Set the initial delay for stats (in millis)\" }"));
-        assertTrue(json.contains("\"groupSize\": { \"kind\": \"parameter\", \"type\": \"integer\", \"javaType\": \"java.lang.Integer\", \"deprecated\": \"false\", \"value\": \"5\","
-                + " \"description\": \"An integer that specifies a group size for throughput logging.\" }"));
-        assertTrue(json.contains("\"loggerName\": { \"kind\": \"path\", \"required\": \"true\", \"type\": \"string\", \"javaType\": \"java.lang.String\", \"deprecated\": \"false\","
-                + " \"value\": \"foo\", \"description\": \"The logger name to use\" }"));
+        assertTrue(json.contains("\"loggerName\": { \"kind\": \"path\", \"group\": \"producer\", \"required\": \"true\""));
+        assertTrue(json.contains("\"groupSize\": { \"kind\": \"parameter\", \"group\": \"producer\", \"type\": \"integer\","
+                + " \"javaType\": \"java.lang.Integer\", \"deprecated\": \"false\", \"value\": \"5\""));
+
         // and we should also have the javadoc documentation
         assertTrue(json.contains("Set the initial delay for stats (in millis)"));
     }
@@ -303,19 +301,15 @@ public class ManagedCamelContextTest extends ManagementTestSupport {
         int pos2 = json.indexOf("groupDelay");
         assertTrue("LoggerName should come before groupDelay", pos < pos2);
 
-        assertEquals(12, StringHelper.countChar(json, '{'));
-        assertEquals(12, StringHelper.countChar(json, '}'));
+        assertEquals(30, StringHelper.countChar(json, '{'));
+        assertEquals(30, StringHelper.countChar(json, '}'));
 
         assertTrue(json.contains("\"scheme\": \"log\""));
         assertTrue(json.contains("\"label\": \"core,monitoring\""));
 
-        assertTrue(json.contains("\"groupDelay\": { \"kind\": \"parameter\", \"type\": \"integer\", \"javaType\": \"java.lang.Long\", \"deprecated\": \"false\", \"value\": \"2000\","
-                + " \"description\": \"Set the initial delay for stats (in millis)\" }"));
-        assertTrue(json.contains("\"groupSize\": { \"kind\": \"parameter\", \"type\": \"integer\", \"javaType\": \"java.lang.Integer\", \"deprecated\": \"false\", \"value\": \"5\","
-                + " \"description\": \"An integer that specifies a group size for throughput logging.\" }"));
-        assertTrue(json.contains("\"loggerName\": { \"kind\": \"path\", \"required\": \"true\", \"type\": \"string\", \"javaType\": \"java.lang.String\", \"deprecated\": \"false\","
-                + " \"value\": \"foo\", \"description\": \"The logger name to use\" }"));
-        assertTrue(json.contains("\"marker\": { \"kind\": \"parameter\", \"type\": \"string\", \"javaType\": \"java.lang.String\""));
+        assertTrue(json.contains("\"loggerName\": { \"kind\": \"path\", \"group\": \"producer\", \"required\": \"true\""));
+        assertTrue(json.contains("\"groupSize\": { \"kind\": \"parameter\", \"group\": \"producer\", \"type\": \"integer\","
+                + " \"javaType\": \"java.lang.Integer\", \"deprecated\": \"false\", \"value\": \"5\""));
         // and we should also have the javadoc documentation
         assertTrue(json.contains("Set the initial delay for stats (in millis)"));
     }

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/test/java/org/apache/camel/management/ManagedEndpointExplainTest.java
----------------------------------------------------------------------
diff --git a/camel-core/src/test/java/org/apache/camel/management/ManagedEndpointExplainTest.java b/camel-core/src/test/java/org/apache/camel/management/ManagedEndpointExplainTest.java
index 195cbc4..0e1ae97 100644
--- a/camel-core/src/test/java/org/apache/camel/management/ManagedEndpointExplainTest.java
+++ b/camel-core/src/test/java/org/apache/camel/management/ManagedEndpointExplainTest.java
@@ -50,7 +50,7 @@ public class ManagedEndpointExplainTest extends ManagementTestSupport {
 
         // there should be 9 in total
         data = (TabularData) mbeanServer.invoke(on, "explain", new Object[]{true}, new String[]{"boolean"});
-        assertEquals(9, data.size());
+        assertEquals(27, data.size());
     }
 
     @Override
diff --git a/camel-core/src/main/java/org/apache/camel/component/dataset/DataSetEndpoint.java b/camel-core/src/main/java/org/apache/camel/component/dataset/DataSetEndpoint.java
index 5de15bd..1847836 100644
--- a/camel-core/src/main/java/org/apache/camel/component/dataset/DataSetEndpoint.java
+++ b/camel-core/src/main/java/org/apache/camel/component/dataset/DataSetEndpoint.java
@@ -48,15 +48,15 @@ public class DataSetEndpoint extends MockEndpoint implements Service {
     private final AtomicInteger receivedCounter = new AtomicInteger();
     @UriPath(name = "name", description = "Name of DataSet to lookup in the registry") @Metadata(required = "true")
     private volatile DataSet dataSet;
-    @UriParam(defaultValue = "0")
+    @UriParam(label = "consuner", defaultValue = "0")
     private int minRate;
-    @UriParam(defaultValue = "3")
+    @UriParam(label = "consuner", defaultValue = "3")
     private long produceDelay = 3;
-    @UriParam(defaultValue = "0")
+    @UriParam(label = "producer", defaultValue = "0")
     private long consumeDelay;
-    @UriParam(defaultValue = "0")
+    @UriParam(label = "consuner", defaultValue = "0")
     private long preloadSize;
-    @UriParam(defaultValue = "1000")
+    @UriParam(label = "consumer", defaultValue = "1000")
     private long initialDelay = 1000;
 
     @Deprecated
@@ -163,7 +163,7 @@ public class DataSetEndpoint extends MockEndpoint implements Service {
     }
 
     /**
      * Allows a delay to be specified which causes consumers to pause - to simulate slow consumers
      */
     public void setConsumeDelay(long consumeDelay) {
         this.consumeDelay = consumeDelay;
@@ -174,7 +174,7 @@ public class DataSetEndpoint extends MockEndpoint implements Service {
     }
 
     /**
      * Allows a delay to be specified which causes producers to pause - to simulate slow producers
      */
     public void setProduceDelay(long produceDelay) {
         this.produceDelay = produceDelay;

http://git-wip-us.apache.org/repos/asf/camel/blob/2bc0d40b/camel-core/src/main/java/org/apache/camel/component/mock/MockEndpoint.java
----------------------------------------------------------------------
@@ -163,7 +163,7 @@ public class DataSetEndpoint extends MockEndpoint implements Service {
 
     /**
-     * Allows a delay to be specified which causes consumers to pause - to simulate slow consumers
+     * Allows a delay to be specified which causes a delay when a message is consumed by the producer (to simulate slow processing)
      */
     public void setConsumeDelay(long consumeDelay) {
@@ -174,7 +174,7 @@ public class DataSetEndpoint extends MockEndpoint implements Service {
 
     /**
-     * Allows a delay to be specified which causes producers to pause - to simulate slow producers
+     * Allows a delay to be specified which causes a delay when a message is sent by the consumer (to simulate slow processing)
      */
     public void setProduceDelay(long produceDelay) {